import time
from calendar import monthrange

from netforce.model import Model,fields,get_model
from netforce.access import get_active_company
from . import utils

STATES={
    'draft': 'Draft',
    'waiting_matching':'Waiting Matching',
    'match':'Match',
    'unmatch':'Unmatch',
    'approved':'Approved',
}

class ReportPaymentMatching(Model):
    _name="clinic.report.payment.matching"
    _string="Report Payment Mathching"
    _transient=True
    
    _fields={
        "date": fields.Date("Month", required=True),
        "date_from": fields.Date("From", required=True),
        "date_to": fields.Date("To", required=True),
        'state': fields.Selection([['draft','Draft'],['waiting_matching','Waiting Matching'],['match','Match'],['unmatch','Unmatch'],['approved','Approved']],'State'),
        'patient_id': fields.Many2One("clinic.patient","Patient"),
        'file': fields.File("File"),
        'type_id': fields.Many2One("clinic.patient.type","Patient Type",required=True),
    }

    def _get_date_from(self,context={}):
        year,month=time.strftime("%Y-%m").split("-")
        return '%s-%s-01'%(year,month)

    def _get_date_to(self,context={}):
        year,month,day=time.strftime("%Y-%m-%d").split("-")
        weekday, total_day=monthrange(int(year), int(month))
        return "%s-%s-%s"%(year,month,total_day)
    
    def _get_type_id(self,context={}):
        st=get_model("clinic.setting").browse(1)
        return st.patient_type_id.id

    _defaults={
        'date': lambda *a: time.strftime("%Y-%m-%d"),
        'date_from': _get_date_from,
        'date_to': _get_date_to,
        'state': 'match',
        'type_id': _get_type_id,
    }

    def match_invoice(self,ids,context={}):
        if not ids:
            print("no ids")
            return
        obj=self.browse(ids)[0]
        if not obj.file:
            raise Exception("File not found!")
        dom=[]
        dom.append(['state','=','waiting_matching'])
        for exp in get_model("clinic.hd.case.expense").search_browse(dom):
            ptype=exp.patient_id.type_id
            if ptype.id==obj.type_id.id:
                exp.write({
                    'match_id': obj.id,
                })
            else:
                exp.write({
                    'match_id': None,
                })
        # TODO
        # udpate check state , write ref (invno)
        
        return {
            'next': {
                'name': 'clinic_report_payment_matching',
                'mode': 'form',
                'active_id': obj.id,
            },
            'flash': 'Match successfully',
        }

    def get_report_data(self,ids,context={}):
        year, month=time.strftime("%Y-%m").split("-")
        lines=[]
        if not ids:
            return
        obj=self.browse(ids)[0]
        dom=[]
        dom.append(['state','=','waiting_matching'])
        dom.append(['match_id','=',obj.id])
        for exp in get_model("clinic.hd.case.expense").search_browse(dom):
            patient=exp.patient_id
            match='No'
            exp_color=""
            if exp.state=='match':
                match='Yes'
            else:
                exp_color='#C0C0C0'
            lines.append({
                'exp_id': exp.id,
                'patient_name': patient.name,
                'patient_id': patient.id,
                'hn': patient.hn,
                'fee_amt': exp.fee_amt or 0,
                'mdc_amt': exp.mdc_amt or 0,
                'srv_amt': exp.srv_amt or 0,
                #'state': STATES[exp.state],
                'match': match,
                'invno': exp.invno,
                'exp_color': exp_color,
            })

        data={
            'lines': lines,
        }
        return data

    def onchange_date(self,context={}):
        data=context['data']
        date=data['date']
        year,month,day=date.split("-")
        weekday, total_day=monthrange(int(year), int(month))
        data['date_from']="%s-%s-01"%(year,month)
        data['date_to']="%s-%s-%s"%(year,month,total_day)
        return data

ReportPaymentMatching.register()
